@@ -3,7 +3,7 @@ package Plack::Middleware::XSRFBlock;
 {
   $Plack::Middleware::XSRFBlock::DIST = 'Plack-Middleware-XSRFBlock';
 }
-$Plack::Middleware::XSRFBlock::VERSION = '0.0.14';
+$Plack::Middleware::XSRFBlock::VERSION = '0.0.15';
 use strict;
 use warnings;
 use parent 'Plack::Middleware';
@@ -48,7 +48,7 @@ sub prepare_app {
     # match content types
     $self->contents_to_filter_regex(
         $self->contents_to_filter_regex ||
-            qr{^(?: (?:text/html) | (?:application/xhtml(?:\+xml)?) )$}ix,
+            qr{^(?: (?:text/html) | (?:application/xhtml(?:\+xml)?) )\b}ix,
     );
 
     # store the cookie_name
@@ -398,7 +398,7 @@ Plack::Middleware::XSRFBlock - Block XSRF Attacks with minimal changes to your a
 
 =head1 VERSION
 
-version 0.0.14
+version 0.0.15
 
 =head1 SYNOPSIS
 
@@ -427,7 +427,7 @@ You may also over-ride any, or all of these values:
             header_name             => undef,
             secret                  => undef,
             http_method_regex       => qr{^post$}i,
-            contents_to_filter_regex => qr{^(text/html|application/xhtml(?:\+xml)?)$}i,
+            contents_to_filter_regex => qr{^(text/html|application/xhtml(?:\+xml)?)\b}i,
             blocked                 => sub {
                                         return [ $status, $headers, $body ]
                                     },
@@ -485,7 +485,7 @@ If this is a coderef, the coderef will be evaluated with the following arguments
 Which HTTP methods to check. Can be useful to also handle PUT, DELETE,
 PATCH, and the like.
 
-=item contents_to_filter_regex default: qr{^(text/html|application/xhtml(?:\+xml)?)$}i)
+=item contents_to_filter_regex default: qr{^(text/html|application/xhtml(?:\+xml)?)\b}i)
 
 Only modify <form> elements in responses whose content type matches this regex
 
